package com.ruoyi.ems.service;

import java.util.List;

import com.ruoyi.ems.domain.EmsEcoD;

/**
 * 节能计量日Service接口
 *
 * @author ruoyi
 * @date 2025-04-22
 */
public interface IEmsEcoDService {
    /**
     * 查询节能计量日
     *
     * @param id 节能计量日主键
     * @return 节能计量日
     */
    EmsEcoD selectEmsEcoDById(Long id);

    /**
     * 查询节能计量日列表
     *
     * @param emsEcoD 节能计量日
     * @return 节能计量日集合
     */
    List<EmsEcoD> selectEmsEcoDList(EmsEcoD emsEcoD);

    /**
     * 新增节能计量日
     *
     * @param emsEcoD 节能计量日
     * @return 结果
     */
    int insertEmsEcoD(EmsEcoD emsEcoD);

    /**
     * 修改节能计量日
     *
     * @param emsEcoD 节能计量日
     * @return 结果
     */
    int updateEmsEcoD(EmsEcoD emsEcoD);

    /**
     * 批量删除节能计量日
     *
     * @param ids 需要删除的节能计量日主键集合
     * @return 结果
     */
    int deleteEmsEcoDByIds(Long[] ids);

    /**
     * 删除节能计量日信息
     *
     * @param id 节能计量日主键
     * @return 结果
     */
    int deleteEmsEcoDById(Long id);

    EmsEcoD calcEmsEcoDateRange(EmsEcoD emsEcoD);
}
